## Title

- Prefix your name with what type of change your making. Supported Types: **feat, fix, docs, style, refactor, perf, test, build, ci, revert, deps**.
- Make your title succinct and descriptive.

- (Good Example) **feat: Server analytics monitor added**

**[REMOVE THIS SECTION BEFORE SUBMISSION]**

## Description

[Provide a detailed explanation of the changes you have made. Include the reasons behind these changes and any relevant context.]

## Changes

[List the changes you have made.]

## Additional Information

[Include any additional information, such as how to test your changes, or any extra information that would be relevant for the reviewer.]

## Submission Checklist

- [ ] My code adheres to the coding and style guidelines.
- [ ] I have commented my code, and added/updated documentation.
- [ ] I have ran all tests, and added/updated any relevant ones.
- [ ] I have formatted and linted my code.
